# ACETONE Authors:

**************************************************
## Main authors:
  * Yanis AIT-AISSA           : <Yanis.AIT-AISSA@student.isae-supaero.fr>
  * Thomas CARLE              : <Thomas.Carle@irit.fr>
  * Iryna DE ALBUQUERQUE SILVA: <Iryna.De_Albuquerque_Silva@onera.fr>
  * Adrien GAUFFRIAU          : <Adrien.Gauffriau@airbus.com>
  * Benjamin LESAGE           : <benjamin.lesage@onera.fr>
  * Claire PAGETTI            : <Claire.Pagetti@onera.fr>
  
**************************************************

